==> haskell-hspec-contrib-0.5.0-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-contrib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-contrib
version: 0.5.0
id: hspec-contrib-0.5.0-IiJs5gWrtXO7EPvRTLz1UF
key: hspec-contrib-0.5.0-IiJs5gWrtXO7EPvRTLz1UF
license: MIT
copyright: (c) 2011-2017 Simon Hengel,
           (c) 2014 Junji Hashimoto
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: Contributed functionality for Hspec
description:
    Contributed functionality for Hspec
category: Testing
abi: 40652259a0c2bc076b7e9fdd6a14bc60
exposed: True
exposed-modules:
    Test.Hspec.Contrib.HUnit Test.Hspec.Contrib.Retry
import-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-contrib-0.5.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-contrib-0.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hspec-contrib-0.5.0
hs-libraries: HShspec-contrib-0.5.0-IiJs5gWrtXO7EPvRTLz1UF
depends:
    base-4.11.1.0 hspec-core-2.5.2-9yo5sXi9naN78n6zxAG5x3
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             hspec-core-2.5.2-9yo5sXi9naN78n6zxAG5x3=b1c4150b7af77d22c2c1e81c0ac77914
             HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=b175aabb3dd9ae95a14a70d0ded5aa16
haddock-interfaces: /usr/share/doc/haskell-hspec-contrib/html/hspec-contrib.haddock
haddock-html: /usr/share/doc/haskell-hspec-contrib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-contrib-0.5.0-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-contrib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-contrib
version: 0.5.0
id: hspec-contrib-0.5.0-FtrDSSETAhc3I9xkP0y8te
key: hspec-contrib-0.5.0-FtrDSSETAhc3I9xkP0y8te
license: MIT
copyright: (c) 2011-2017 Simon Hengel,
           (c) 2014 Junji Hashimoto
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: Contributed functionality for Hspec
description:
    Contributed functionality for Hspec
category: Testing
abi: d433b5ce32813454440f53fbf9971a31
exposed: True
exposed-modules:
    Test.Hspec.Contrib.HUnit Test.Hspec.Contrib.Retry
import-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-contrib-0.5.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-contrib-0.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hspec-contrib-0.5.0
hs-libraries: HShspec-contrib-0.5.0-FtrDSSETAhc3I9xkP0y8te
depends:
    base-4.11.1.0 hspec-core-2.5.3-Ams2XuOnNDi8kkLterMX9N
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             hspec-core-2.5.3-Ams2XuOnNDi8kkLterMX9N=e0a953b556df722532d5f3ec3bd0085a
             HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=b175aabb3dd9ae95a14a70d0ded5aa16
haddock-interfaces: /usr/share/doc/haskell-hspec-contrib/html/hspec-contrib.haddock
haddock-html: /usr/share/doc/haskell-hspec-contrib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
